/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.sinfo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.dive4elements.river.model.River;

/**
 * Hibernate binding for the DB table tkh
 *
 * @author Matthias Schäfer
 *
 */

@Entity
@Table(name = "tkh")
public class Tkh implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = 5891445651697221261L;

    private Integer id;

    private River river;

    private String filename;

    private String kmrange_info;

    private String comment;

    private Integer year;

    private String sounding_info;

    private String evaluation_by;

    private List<TkhColumn> columns;


    /***** CONSTRUCTORS *****/

    public Tkh() {
    }


    public Tkh(final River river, final String filename, final String kmrange_info, final String comment, final Integer year, final String sounding_info,
            final String evaluation_by) {
        this.river = river;
        this.filename = filename;
        this.kmrange_info = kmrange_info;
        this.comment = comment;
        this.year = year;
        this.setSounding_info(sounding_info);
        this.setEvaluation_by(evaluation_by);
        this.columns = new ArrayList<>();
    }

    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_TKH_ID_SEQ", sequenceName = "TKH_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_TKH_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "filename")
    public String getFilename() {
        return this.filename;
    }

    public void setFilename(final String filename) {
        this.filename = filename;
    }

    @Column(name = "kmrange_info")
    public String getKmrange_info() {
        return this.kmrange_info;
    }

    public void setKmrange_info(final String kmrange_info) {
        this.kmrange_info = kmrange_info;
    }

    @Column(name = "comment")
    public String getComment() {
        return this.comment;
    }

    public void setComment(final String comment) {
        this.comment = comment;
    }

    @Column(name = "year")
    public Integer getYear() {
        return this.year;
    }

    public void setYear(final Integer year) {
        this.year = year;
    }

    @Column(name = "sounding_info")
    public String getSounding_info() {
        return this.sounding_info;
    }

    public void setSounding_info(final String sounding_info) {
        this.sounding_info = sounding_info;
    }

    @Column(name = "evaluation_by")
    public String getEvaluation_by() {
        return this.evaluation_by;
    }

    public void setEvaluation_by(final String evaluation_by) {
        this.evaluation_by = evaluation_by;
    }

    @OneToMany
    @JoinColumn(name = "tkh_id")
    public List<TkhColumn> getColumns() {
        return this.columns;
    }

    public void setColumns(final List<TkhColumn> values) {
        this.columns = values;
    }

    public void addColumn(final TkhColumn value) {
        this.columns.add(value);
    }
}